     H Debug(*Yes) Indent('| ') NoMain
      *---------------------------------------------------------------------
      * Program: GETSVCUSR - Get service job user profile
      * Author:  Brent Sauser
      * Date:    08/27/1999
      *
      * Description:
      *   This program gets the user profile of a service job running from
      *   a PC.  The user profile on the AS/400 is QUSER, but the actual
      *   user profile is retrieved from the joblog.
      *
      * Input:
      * Output:  Actual user profile
      *
      * Special Instructions: None
      *---------------------------------------------------------------------

      * System API error code
      /Copy Qsysinc/Qrpglesrc,Qusec

      /Copy Qcpylesrc,Getsvcusrh

      *---------------------------------------------------------------------
      * Get service job user profile
      *---------------------------------------------------------------------
     p GetSvcUsr       b                   Export

     d GetSvcUsr       pi            10

      * User space name
     d UsrSpcNam       s             20    Inz('JOBLOGSPC QTEMP     ')

      * User space header structure
     d SpcHdrP         s               *
     d SpcHdr          ds                  Based(SpcHdrP)
     d  SpcDtaStr            125    128i 0
     d  SpcNumLst            133    136i 0
     d  SpcEntSiz            137    140i 0

      * List joblog messages entry structure
     d MsgEntP         s               *
     d MsgEntDs        ds          2000    Based(MsgEntP)
     d  NxtEntOff              1      4i 0
     d  FldRetOff              5      8i 0
     d  NumFldRet              9     12i 0
     d  MsgSev                13     16i 0
     d  MsgId                 17     23
     d  MsgTyp                24     25
     d  MsgKey                26     29
     d  MsgDta                30   2000

      * List joblog messages field structure
     d MsgFldP         s               *
     d MsgFldDs        ds            42    Based(MsgFldP)
     d  NxtFldOff              1      4i 0
     d  FldRetLen              5      8i 0
     d  IdFld                  9     12i 0
     d  DataType              13     13
     d  DataSts               14     14
     d  DataLen               29     32i 0
     d  Data                  33     42

      * List joblog messages selection structure
     d MsgSelDs        ds           300
     d  MaxMsgs                1      4i 0 Inz(20)
     d  ListDir                5     14    Inz('*NEXT')
     d  JobName               15     40    Inz('*')
     d  IntJobId              41     56    Inz(*blank)
     d  StrMsgKey             57     60    Inz(X'00000000')
     d  MaxMsgLen             61     64i 0 Inz(10)
     d  MaxHlpLen             65     68i 0 Inz(10)
     d  FldIdOff              69     72i 0
     d  GetNumFld             73     76i 0 Inz(1)
     d  MsgQueOff             77     80i 0
     d  MsgQueSiz             81     84i 0 Inz(1)
     d  FldIds                85     88i 0 Inz(0201)
     d  MsgQueNam             89     89    Inz('*')

     d FmtNam          s              8    Inz('LJOB0100')
     d MsgSelSiz       s             10i 0
     d MsgSelFmt       s              8    Inz('JSLT0100')
     d UserId          s             10

      * Initial setup
     c                   clear                   UserId
     c                   eval      MsgSelSiz = %size(MsgSelDs)
     c                   eval      FldIdOff = %addr(FldIds) - %addr(MsgSelDs)
     c                   eval      MsgQueOff = %addr(MsgQueNam) -
     c                               %addr(MsgSelDs)

      * Create the user space
     c                   callp     CrtUsrSpc(UsrSpcNam)

      * List joblog messages
     c                   call      'QMHLJOBL'
     c                   parm                    UsrSpcNam
     c                   parm                    FmtNam
     c                   parm                    MsgSelDs
     c                   parm                    MsgSelSiz
     c                   parm                    MsgSelFmt
     c                   parm                    Qusec

      * If any errors, dump and exit out
     c                   if        Qusbavl > 0
     c                   exsr      *PSSR
     c                   endif

      * Get the user space pointer
     c                   eval      SpcHdrP = GetSpcPtr(UsrSpcNam)

      * Step through the user space entries to find joblog message
      * CPIAD02 - servicing user profile &1.
     c                   eval      MsgEntP = SpcHdrP + SpcDtaStr
     c     2             do        SpcNumLst
     c                   if        MsgId = 'CPIAD02'
     c                   eval      MsgFldP = SpcHdrP + FldRetOff
     c                   eval      UserId = Data
     c                   leave
     c                   endif
     c                   eval      MsgEntP = SpcHdrP + NxtEntOff
     c                   enddo

     c                   return    UserId

      *---------------------------------------------------------------------
     c     *PSSR         begsr
     c                   dump
     c                   return    *blank
     c                   endsr

     p GetSvcUsr       e

      *---------------------------------------------------------------------
      * Create the user space
      *---------------------------------------------------------------------
     p CrtUsrSpc       b

     d CrtUsrSpc       pi
     d  UsrSpcNam                    20

     d UsrSpcAtr       s             10    Inz(*blank)
     d UsrSpcSiz       s             10i 0 Inz(8192)
     d UsrSpcInz       s              1    Inz(X'00')
     d UsrSpcAut       s             10    Inz('*CHANGE')
     d UsrSpcTxt       s             50    Inz(*blank)
     d UsrSpcRpl       s             10    Inz('*YES')

      * Create the user space
     c                   call      'QUSCRTUS'
     c                   parm                    UsrSpcNam
     c                   parm                    UsrSpcAtr
     c                   parm                    UsrSpcSiz
     c                   parm                    UsrSpcInz
     c                   parm                    UsrSpcAut
     c                   parm                    UsrSpcTxt
     c                   parm                    UsrSpcRpl
     c                   parm                    Qusec

     p CrtUsrSpc       e

      *---------------------------------------------------------------------
      * Delete the user space
      *---------------------------------------------------------------------
     p DltUsrSpc       b

     d DltUsrSpc       pi
     d  UsrSpcNam                    20

      * Delete the user space
     c                   call      'QUSDLTUS'
     c                   parm                    UsrSpcNam
     c                   parm                    Qusec

     p DltUsrSpc       e

      *---------------------------------------------------------------------
      * Get pointer to user space
      *---------------------------------------------------------------------
     p GetSpcPtr       b

     d GetSpcPtr       pi              *
     d  UsrSpcNam                    20

     d UsrSpcPtr       s               *

      * Get the pointer to the user space
     c                   call      'QUSPTRUS'
     c                   parm                    UsrSpcNam
     c                   parm                    UsrSpcPtr
     c                   parm                    Qusec

     c                   return    UsrSpcPtr

     p GetSpcPtr       e
